# {{folder_name}}

{{folder_name}} is a Peeps AI Tool. This template is designed to help you create
custom tools to power up your peepz.

## Installing

Ensure you have Python >=3.10 <3.13 installed on your system. This project
uses [UV](https://docs.astral.sh/uv/) for dependency management and package
handling, offering a seamless setup and execution experience.

First, if you haven't already, install `uv`:

```bash
pip install uv
```

Next, navigate to your project directory and install the dependencies with:

```bash
peepsai install
```

## Publishing

Collaborate by sharing tools within your organization, or publish them publicly
to contribute with the community.

```bash
peepsai tool publish {{tool_name}}
```

Others may install your tool in their peepz running:

```bash
peepsai tool install {{tool_name}}
```

## Support

For support, questions, or feedback regarding the {{peeps_name}} Peeps or Peeps AI.

- Visit our [documentation](https://docs.peepsai.io)
- Reach out to us through our [GitHub repository](https://github.com/PeepsAI/peepsai)
- [Join our Telegram](https://t.me/peeps_ai)

Let's create wonders together with the power and simplicity of Peeps AI.
